#!/bin/bash
set -e

INFILE=/dev/stdin
OUTFILE=/dev/stdout

PORT=
LANGPAIR=

while [[ $# -gt 0 ]]; do
    key="$1"
    case $key in
        -i|--input)
            INFILE="$2"
            shift
        ;;
        -o|--output)
            OUTFILE="$2"
            shift
        ;;
        --port)
            PORT="$2"
            shift
        ;;
        --model)
            LANGPAIR="$2"
            shift
        ;;
        *)
            echo Unknown option '"'$key'"' >&2
            exit 1
        ;;
    esac
    shift
done

function err_exit {
    echo $@ >&2 && exit 1
}

[[ -z "$LANGPAIR" ]] && err_exit 'Model specification option missing (e.g. --model en-cs)'
[[ -z "$PORT" ]] && err_exit 'Please specify the port on which the docker container with the translation model is listening on'

docker ps > /tmp/translation.$$
cat /tmp/translation.$$ | grep $LANGPAIR > /dev/null || err_exit "A docker container for $LANGPAIR model is not running"
cat /tmp/translation.$$ | grep 127.0.0.1:$PORT > /dev/null || err_exit "A docker container running on port $PORT is not running"

curl \
    -X POST \
    -H "Content-Type: text/plain" \
    -d "`cat $INFILE`" 127.0.0.1:$PORT/translation/$LANGPAIR | \
    python -c 'import sys, json; print(json.load(sys.stdin)["response"]["texts"][0]["content"])' > $OUTFILE
